#
# spec file for package pulseview
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pulseview
Version:        0.4.2
Release:        bp156.3.8
Summary:        Qt-based GUI for sigrok
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Electronics
URL:            https://sigrok.org
Source0:        https://sigrok.org/download/source/pulseview/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE
Patch0:         0001-Fix-building-with-Qt-5.15.patch
# PATCH-FIX-UPSTREAM
Patch1:         0001-Fix-broken-build-due-to-C-template-behind-C-linkage.patch
BuildRequires:  cmake
BuildRequires:  glib2-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_serialization-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_test-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  libsigrok-devel >= 0.5.2
BuildRequires:  libsigrokdecode-devel >= 0.5.2
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Widgets)

%description
The sigrok project aims at creating a portable, cross-platform,
Free/Libre/Open-Source logic analyzer software that supports various
logic analyzer hardware products.

PulseView is a Qt-based GUI for sigrok.

%prep
%autosetup -p1

%build
export CXXFLAGS="%{optflags} -fpermissive"
%cmake -DDISABLE_WERROR=TRUE ..
%cmake_build

%install
%cmake_install
find %{buildroot} -type f -name "*.la" -delete -print

install -m 644 -D icons/pulseview.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/pulseview.png
install -m 644 -D icons/pulseview.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/pulseview.svg

install -m 755 -d %{buildroot}%{_datadir}/applications/
install -m 644 contrib/org.sigrok.PulseView.desktop %{buildroot}%{_datadir}/applications/org.sigrok.PulseView.desktop
%suse_update_desktop_file -r org.sigrok.PulseView Education Engineering

install -m 755 -d %{buildroot}%{_datadir}/metainfo/
install -m 644 contrib/org.sigrok.PulseView.appdata.xml %{buildroot}%{_datadir}/metainfo/org.sigrok.PulseView.appdata.xml

%files
%license COPYING
%doc NEWS README HACKING
%{_bindir}/*
%{_mandir}/man1/pulseview.*
%{_datadir}/applications/*
%{_datadir}/icons/hicolor/*/apps/pulseview*
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.sigrok.PulseView.appdata.xml

%changelog
* Wed Apr 28 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with GLib 2.68, add
  0001-Fix-broken-build-due-to-C-template-behind-C-linkage.patch
* Mon Jun 22 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build, add 0001-Fix-building-with-Qt-5.15.patch
* Wed Apr  1 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.4.2
  * PulseView session setups can now be saved/restored to and
    from *.pvs files.
  * Translation support was added to the GUI elements (and a first
    translation, German, is available). Please check the wiki for
    details on how you can contribute further translations.
  * There's a new protocol decoder selection subwindow with
    filtering capabilities, browing by decoder tags, auto-stacking
    of decoders where required, and more.
  * A new decoder "binary" output subwindow can show/save
    "OUTPUT_BINARY" type decoder data in various (decoder-specific)
    formats (WAV, PCAP, PNG, and many others). This also features
    a simple "hex view" for the data.
  * It is now possible to show/hide individual decoder annotation
    rows, and individual annotation classes. This is very handy
    when you're debugging a specific issue and only want to see
    certain classes of decoder annotations, e.g. "show me only CRC
    errors", "show me only parity errors and frame errors", or
    "show me only I²C NACKs" etc. etc.
  * Lots of UI and functionality improvements regarding cursors
    and markers.
  * Various new handy key shortcuts for zooming, moving around in
    the data, placing cursors, etc.
  * Various drawing and decoder/annotation performance improvements.
- This requires libsigrok >= 0.5.2 (already released for some time)
* Tue Mar 19 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Explicitly BuildRequire: libboost_system-devel, required since Boost 1.69
* Tue Oct 30 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.4.1
  * Snapping cursors to signal edges
  * New command-line switches, see manpage
  * Converting analog channels to digital/logic channels
  * Theme support
  * UI improvements
  * Protocol decoder annotations can be exported
  * Improved channel name auto-mapping
  * Performance and memory usage improvements
  * Huge amount of fixes
  See https://www.sigrok.org/blog/pulseview-041-released for details
* Tue Jun 13 2017 stefan.bruens@rwth-aachen.de
- Update to version 0.4.0
  * Add the concepts of sessions and views to PulseView:
  - Sessions represent individual files/device instances.
    Each session is represented as a tab in PulseView.
  - Views are different data representations of one specific session.
    For example, different views of a session can have different zoom levels,
    can be scrolled to different positions, etc. etc.
    Each view is a dock window within the respective session's tab.
  - The view docks can be repositioned, resized and extracted out into their
    own individual windows.
  * Add support for saving analog data to .sr files.
  * Lots of fixes and improvements
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sat Oct 22 2016 stefan.bruens@rwth-aachen.de
- Add org.sigrok.Pulseview.appdata.xml
- Install desktop file and icons for pulseview, register pulseview
  as handler for application/x-sigrok-dump mimetype
* Tue Oct 11 2016 stefan.bruens@rwth-aachen.de
- Add -fext-numeric-literals compiler flag as workaround for
  boo#1004168
* Sat Jan 30 2016 stefan.bruens@rwth-aachen.de
- Update to version 0.3.0
  * Support for vertical scaling of analog or logic traces
  * A "Save selection range as..." feature
  * Some settings now survive a restart (last open/save directory
    location, window size/position, last used device)
  * Pinch-zoom support, always-zoom-to-fit support,
    "sticky scrolling" support, etc.
  * Trace group support (for dragging multiple traces around as a
    group)
  * ...and many, many more GUI and usability improvements...
* Fri Sep 25 2015 stefan.bruens@rwth-aachen.de
- Track GIT version
* Sun Aug  3 2014 dmitry_r@opensuse.org
- Remove redefined cmake macros
* Mon Jun  2 2014 bugs@vdm-design.de
- Sync .spec with the one from rmax
* Fri May 30 2014 bugs@vdm-design.de
- Update to version 0.2.0
  * Support for protocol decoding (via libsigrokdecode) has been added, including support for annotation rows, multiple decoders in the same GUI window, support for stacking protocol decoders (e.g. I²C -> RTC8564, UART -> MIDI, or SPI -> SDcard) and lots more.
  * Support for loading and saving sigrok session (*.sr) files has been added.
  * Initial support for analog data sources (specifically oscilloscopes, e.g. the Rigol DS1052E) has been added.
* Tue Jan 29 2013 max@suse.com
- Upstream adopted pulseview-pthread.patch
- Disable -Werror to fix build.
* Thu Jan 17 2013 max@suse.com
- Explicitly link against libpthread (pulseview-pthread.patch).
* Wed Jan 16 2013 max@suse.com
- Initial build from git snapshot.
